@@ -13,8 +13,8 @@
 #' @title Extract daily levels information from the HYDAT database
 #'
 #' @description Provides wrapper to turn the DLY_LEVELS table in HYDAT into a tidy data frame.  The primary value returned by this 
-#' function is discharge. \code{station_number} and \code{prov_terr_state_loc} can both be supplied. If both are omitted all 
-#' values from the \code{hy_stations} table are returned. That is a large vector for \code{hy_daily_levels}.
+#' function is discharge. `station_number` and `prov_terr_state_loc` can both be supplied. If both are omitted all 
+#' values from the `hy_stations` table are returned. That is a large vector for `hy_daily_levels`.
 #'
 #' @inheritParams hy_daily_flows
 #'
@@ -56,7 +56,7 @@ hy_daily_levels <- function(station_number = NULL,
   ## Read in database
   hydat_con <- hy_src(hydat_path)
   if (!dplyr::is.src(hydat_path)) {
-    on.exit(hy_src_disconnect(hydat_con))
+    on.exit(hy_src_disconnect(hydat_con), add = TRUE)
   }
 
   ## Determine which stations we are querying
