@@ -1,7 +1,5 @@
-context("Testing minor lookup tables for STN_* functions")
-
 test_that("hy_stn_remarks returns a dataframe", {
-  expect_is(hy_stn_remarks(
+  expect_s3_class(hy_stn_remarks(
     station_number = "08MF005",
     hydat_path = hy_test_db()
   ),
@@ -9,7 +7,7 @@ test_that("hy_stn_remarks returns a dataframe", {
 })
 
 test_that("hy_stn_datum_conv returns a dataframe", {
-  expect_is(hy_stn_datum_conv(
+  expect_s3_class(hy_stn_datum_conv(
     station_number = "08MF005",
     hydat_path = hy_test_db()
   ),
@@ -19,7 +17,7 @@ test_that("hy_stn_datum_conv returns a dataframe", {
 ##Not testing STN_DATUM_UNRELALTED because there are so few stations in the database
 
 test_that("hy_stn_data_range returns a dataframe", {
-  expect_is(hy_stn_data_range(
+  expect_s3_class(hy_stn_data_range(
     station_number = "08MF005",
     hydat_path = hy_test_db()
   ),
@@ -27,7 +25,7 @@ test_that("hy_stn_data_range returns a dataframe", {
 })
 
 test_that("hy_stn_data_coll returns a dataframe", {
-  expect_is(hy_stn_data_coll(
+  expect_s3_class(hy_stn_data_coll(
     station_number = "08MF005",
     hydat_path = hy_test_db()
   ),
@@ -35,7 +33,7 @@ test_that("hy_stn_data_coll returns a dataframe", {
 })
 
 test_that("hy_stn_op_schedule returns a dataframe", {
-  expect_is(hy_stn_op_schedule(
+  expect_s3_class(hy_stn_op_schedule(
     station_number = "08MF005",
     hydat_path = hy_test_db()
   ),
@@ -47,4 +45,3 @@ test_that("hy_stn_data_range contains properly coded NA's",{
   expect_true(is.na(hy_stn_data_range(hydat_path = hy_test_db())$SED_DATA_TYPE[1]))
 })
 
-##Not testing STN_DATUM_UNRELALTED because there are so few stations in the database
